# UnionAI

The SDK for [Union.ai](https://www.union.ai/).

## Account Creation

To get started with Union serverless:

- Create an account on
[github.com](https://github.com/).
- Go to the serverless tenant on your browser: https://serverless-gcp.cloud-staging.union.ai
- Click **Sign in with GitHub**, and you should be taken to the Union serverless
console.
- Now you're ready to start using Union serverless!

## Installation

Install `unionai`:

```bash
pip install unionai
```
